summaryrefslogtreecommitdiff
path: root/lisp/mail/sendmail.el
diff options
context:
space:
mode:
authorGlenn Morris <rgm@gnu.org>2019-02-20 12:07:22 -0800
committerGlenn Morris <rgm@gnu.org>2019-02-20 12:07:22 -0800
commit83a9133e35827c1edbd8bf24a17ffa3b4bfb7be3 (patch)
tree11d2812db4a9ee4e66976b3a5f1e5ecbe52b4955 /lisp/mail/sendmail.el
parentae77728d14e58054bdaee3c6965979947c778208 (diff)
parentff9c9620794e5fe5692cfd3badd207aac78921cb (diff)
downloademacs-83a9133e35827c1edbd8bf24a17ffa3b4bfb7be3.tar.gz
Merge from origin/emacs-26
ff9c962 ; * lisp/ldefs-boot.el: Update. b4a251c * ; ChangeLog.3 update d3104e3 * etc/AUTHORS: Update. a19bfb7 Remove .art from the default list of ImageMagick extensions 6985caa Fix input after setting x-wait-for-event-timeout nil 715388a Fix two warnings in eshell.texi d49cdd9 * lisp/minibuffer.el (completion-table-dynamic): Improve docs... 5dc4e51 * lisp/emacs-lisp/debug.el (debug-on-variable-change): Doc fi... 76ef805 Fix a typo in ELisp manual b5e66f4 Update citations of Internet RFCs 57ece2a Fix handling of manpage references divided by hyphenation 7ad0cd6 * doc/misc/eshell.texi: Fix some @ref's. 12b7940 Fix a typo in lispref/syntax.texi # Conflicts: # lisp/gnus/nnrss.el # lisp/mail/ietf-drums.el
Diffstat (limited to 'lisp/mail/sendmail.el')
-rw-r--r--lisp/mail/sendmail.el9
1 files changed, 4 insertions, 5 deletions
diff --git a/lisp/mail/sendmail.el b/lisp/mail/sendmail.el
index 9315d6ac627..93b6c90521b 100644
--- a/lisp/mail/sendmail.el
+++ b/lisp/mail/sendmail.el
@@ -150,7 +150,7 @@ Otherwise, let mailer send back a message to report errors."
'smtpmail-send-it 'sendmail-query-once)
"Function to call to send the current buffer as mail.
The headers should be delimited by a line which is
-not a valid RFC822 header or continuation line,
+not a valid RFC 822 (or later) header or continuation line,
that matches the variable `mail-header-separator'.
This is used by the default mail-sending commands. See also
`message-send-mail-function' for use with the Message package."
@@ -908,7 +908,7 @@ the user from the mailer."
(ml (when mail-mailing-lists
;; The surrounding regexp assumes the use of
;; `mail-strip-quoted-names' on addresses before matching
;; Cannot deal with full RFC 822 freedom, but that is
;; unlikely to be problematic.
(concat "\\(?:[[:space:];,]\\|\\`\\)"
(regexp-opt mail-mailing-lists t)
@@ -1044,7 +1044,7 @@ This function does not perform RFC2047 encoding."
(fullname-end (point-marker)))
(goto-char fullname-start)
;; Look for a character that cannot appear unquoted
;; according to RFC 822.
(if (or (re-search-forward "[^- !#-'*+/-9=?A-Z^-~]"
fullname-end 1)
quote-fullname)
@@ -1068,8 +1068,7 @@ This function does not perform RFC2047 encoding."
(insert "\""))
(let ((fullname-end (point-marker)))
(goto-char fullname-start)
- ;; RFC 822 says \ and nonmatching parentheses
- ;; must be escaped in comments.
+ ;; \ and nonmatching parentheses must be escaped in comments.
;; Escape every instance of ()\ ...
(while (re-search-forward "[()\\]" fullname-end 1)
(replace-match "\\\\\\&" t))
@@ -908,7 +908,7 @@ the user from the mailer."
;; The surrounding regexp assumes the use of
;; `mail-strip-quoted-names' on addresses before matching
- ;; Cannot deal with full RFC 822 freedom, but that is
+ ;; Cannot deal with full RFC 822 (or later), but that is
;; unlikely to be problematic.
(concat "\\(?:[[:space:];,]\\|\\`\\)"
@@ -1044,7 +1044,7 @@ This function does not perform RFC2047 encoding."
(goto-char fullname-start)
;; Look for a character that cannot appear unquoted
- ;; according to RFC 822.
+ ;; according to RFC 822 (or later).
(if (or (re-search-forward "[^- !#-'*+/-9=?A-Z^-~]"
fullname-end 1)